#!/bin/bash

Add_Iptables_Rules()
{
    #add iptables firewall rules
    if [ -s /sbin/iptables ]; then
        /sbin/iptables -I INPUT 1 -i lo -j ACCEPT
        /sbin/iptables -I INPUT 2 -m state --state ESTABLISHED,RELATED -j ACCEPT
        /sbin/iptables -I INPUT 3 -p tcp --dport 22 -j ACCEPT
        /sbin/iptables -I INPUT 4 -p tcp --dport 80 -j ACCEPT
        /sbin/iptables -I INPUT 5 -p tcp --dport 443 -j ACCEPT
        /sbin/iptables -I INPUT 6 -p tcp --dport 8000 -j ACCEPT
        /sbin/iptables -I INPUT 7 -p tcp --dport 3306 -j DROP
        /sbin/iptables -I INPUT 8 -p icmp -m icmp --icmp-type 8 -j ACCEPT
        if [ "$PM" = "yum" ]; then
            service iptables save
            if [ -s /usr/sbin/firewalld ]; then
                systemctl stop firewalld
                systemctl disable firewalld
            fi
        elif [ "$PM" = "apt" ]; then
            iptables-save > /etc/iptables.rules
            cat >/etc/network/if-post-down.d/iptables<<EOF
#!/bin/bash
iptables-save > /etc/iptables.rules
EOF
            chmod +x /etc/network/if-post-down.d/iptables
            cat >/etc/network/if-pre-up.d/iptables<<EOF
#!/bin/bash
iptables-restore < /etc/iptables.rules
EOF
            chmod +x /etc/network/if-pre-up.d/iptables
        fi
    fi
}

Add_LFZM_Startup()
{
    echo "Add Startup and Starting LFZM..."
    StartUp nginx-lfzm
    /etc/init.d/nginx-lfzm start
    StartUp php-fpm-lfzm
    /etc/init.d/php-fpm-lfzm start
}


Check_Nginx_Files()
{
    isNginx=""
    echo "============================== Check install =============================="
    echo "Checking ..."
    if [[ -s /usr/local/lfzm/nginx/conf/nginx.conf && -s /usr/local/lfzm/nginx/sbin/nginx ]]; then
        Echo_Green "Nginx: OK"
        isNginx="ok"
    else
        Echo_Red "Error: Nginx install failed."
    fi
}


Check_PHP_Files()
{
    isPHP=""
    if [[ -s /usr/local/lfzm/php/sbin/php-fpm && -s /usr/local/lfzm/php/etc/php.ini && -s /usr/local/lfzm/php/bin/php ]]; then
        Echo_Green "PHP: OK"
        Echo_Green "PHP-FPM: OK"
        isPHP="ok"
    else
        Echo_Red "Error: PHP install failed."
    fi
}

Clean_Src_Dir()
{
    rm -rf ${cur_dir}/src/${Php_Ver}
    rm -rf ${cur_dir}/src/${Nginx_Ver}
}

Print_Sucess_Info()
{
    Clean_Src_Dir
    echo "+------------------------------------------------------------------------+"
    echo "|          LFZM V${LFZM_Ver} for ${DISTRO} Linux Server, Written by Licess          |"
    echo "+------------------------------------------------------------------------+"
    echo "|           For more information please visit http://www.lfdycms.com     |"
    echo "+------------------------------------------------------------------------+"
    echo "|  Default directory: ${Default_Website_Dir}                              |"
    echo "+------------------------------------------------------------------------+"
    if [ -s /bin/ss ]; then
        ss -ntl
    else
        netstat -ntl
    fi
    stop_time=$(date +%s)
    echo "Install lnmp takes $(((stop_time-start_time)/60)) minutes."
    Echo_Green "Install lnmp V${LFZM_Ver} completed! enjoy it."
}

Print_Failed_Info()
{
    Echo_Red "Sorry, Failed to install LFZM!"
    Echo_Red "You can download /root/lnmp-install.log from your server,and upload lnmp-install.log to LFZM Forum."
}

Check_LFZM_Install()
{
    Check_Nginx_Files
    Check_PHP_Files
    if [[ "${isNginx}" = "ok" && "${isPHP}" = "ok" ]]; then
        Print_Sucess_Info
    else
        Print_Failed_Info
    fi
}
